==> open-cluster-management-cluster-model-6.4.0-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/PlacementSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PlacementSpecFluent<A extends PlacementSpecFluent<A>> extends Fluent<A>{
  public A addToClusterSets(Integer index,String item);
  public A setToClusterSets(Integer index,String item);
  public A addToClusterSets(java.lang.String... items);
  public A addAllToClusterSets(Collection<String> items);
  public A removeFromClusterSets(java.lang.String... items);
  public A removeAllFromClusterSets(Collection<String> items);
  public List<String> getClusterSets();
  public String getClusterSet(Integer index);
  public String getFirstClusterSet();
  public String getLastClusterSet();
  public String getMatchingClusterSet(Predicate<String> predicate);
  public Boolean hasMatchingClusterSet(Predicate<String> predicate);
  public A withClusterSets(List<String> clusterSets);
  public A withClusterSets(java.lang.String... clusterSets);
  public Boolean hasClusterSets();
  public Integer getNumberOfClusters();
  public A withNumberOfClusters(Integer numberOfClusters);
  public Boolean hasNumberOfClusters();
  public A addToPredicates(Integer index,ClusterPredicate item);
  public A setToPredicates(Integer index,ClusterPredicate item);
  public A addToPredicates(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.ClusterPredicate... items);
  public A addAllToPredicates(Collection<ClusterPredicate> items);
  public A removeFromPredicates(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.ClusterPredicate... items);
  public A removeAllFromPredicates(Collection<ClusterPredicate> items);
  public A removeMatchingFromPredicates(Predicate<ClusterPredicateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPredicates instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterPredicate> getPredicates();
  public List<ClusterPredicate> buildPredicates();
  public ClusterPredicate buildPredicate(Integer index);
  public ClusterPredicate buildFirstPredicate();
  public ClusterPredicate buildLastPredicate();
  public ClusterPredicate buildMatchingPredicate(Predicate<ClusterPredicateBuilder> predicate);
  public Boolean hasMatchingPredicate(Predicate<ClusterPredicateBuilder> predicate);
  public A withPredicates(List<ClusterPredicate> predicates);
  public A withPredicates(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.ClusterPredicate... predicates);
  public Boolean hasPredicates();
  public PlacementSpecFluent.PredicatesNested<A> addNewPredicate();
  public PlacementSpecFluent.PredicatesNested<A> addNewPredicateLike(ClusterPredicate item);
  public PlacementSpecFluent.PredicatesNested<A> setNewPredicateLike(Integer index,ClusterPredicate item);
  public PlacementSpecFluent.PredicatesNested<A> editPredicate(Integer index);
  public PlacementSpecFluent.PredicatesNested<A> editFirstPredicate();
  public PlacementSpecFluent.PredicatesNested<A> editLastPredicate();
  public PlacementSpecFluent.PredicatesNested<A> editMatchingPredicate(Predicate<ClusterPredicateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPrioritizerPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public PrioritizerPolicy getPrioritizerPolicy();
  public PrioritizerPolicy buildPrioritizerPolicy();
  public A withPrioritizerPolicy(PrioritizerPolicy prioritizerPolicy);
  public Boolean hasPrioritizerPolicy();
  public PlacementSpecFluent.PrioritizerPolicyNested<A> withNewPrioritizerPolicy();
  public PlacementSpecFluent.PrioritizerPolicyNested<A> withNewPrioritizerPolicyLike(PrioritizerPolicy item);
  public PlacementSpecFluent.PrioritizerPolicyNested<A> editPrioritizerPolicy();
  public PlacementSpecFluent.PrioritizerPolicyNested<A> editOrNewPrioritizerPolicy();
  public PlacementSpecFluent.PrioritizerPolicyNested<A> editOrNewPrioritizerPolicyLike(PrioritizerPolicy item);
  public interface PredicatesNested<N> extends Nested<N>,ClusterPredicateFluent<PlacementSpecFluent.PredicatesNested<N>>{
    public N and();
    public N endPredicate();
    
  }
  public interface PrioritizerPolicyNested<N> extends Nested<N>,PrioritizerPolicyFluent<PlacementSpecFluent.PrioritizerPolicyNested<N>>{
    public N and();
    public N endPrioritizerPolicy();
    
  }
  
}

==> open-cluster-management-cluster-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/PlacementSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PlacementSpecFluent<A extends PlacementSpecFluent<A>> extends Fluent<A>{
  public A addToClusterSets(int index,String item);
  public A setToClusterSets(int index,String item);
  public A addToClusterSets(java.lang.String... items);
  public A addAllToClusterSets(Collection<String> items);
  public A removeFromClusterSets(java.lang.String... items);
  public A removeAllFromClusterSets(Collection<String> items);
  public List<String> getClusterSets();
  public String getClusterSet(int index);
  public String getFirstClusterSet();
  public String getLastClusterSet();
  public String getMatchingClusterSet(Predicate<String> predicate);
  public Boolean hasMatchingClusterSet(Predicate<String> predicate);
  public A withClusterSets(List<String> clusterSets);
  public A withClusterSets(java.lang.String... clusterSets);
  public Boolean hasClusterSets();
  public Integer getNumberOfClusters();
  public A withNumberOfClusters(Integer numberOfClusters);
  public Boolean hasNumberOfClusters();
  public A addToPredicates(int index,ClusterPredicate item);
  public A setToPredicates(int index,ClusterPredicate item);
  public A addToPredicates(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.ClusterPredicate... items);
  public A addAllToPredicates(Collection<ClusterPredicate> items);
  public A removeFromPredicates(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.ClusterPredicate... items);
  public A removeAllFromPredicates(Collection<ClusterPredicate> items);
  public A removeMatchingFromPredicates(Predicate<ClusterPredicateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPredicates instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterPredicate> getPredicates();
  public List<ClusterPredicate> buildPredicates();
  public ClusterPredicate buildPredicate(int index);
  public ClusterPredicate buildFirstPredicate();
  public ClusterPredicate buildLastPredicate();
  public ClusterPredicate buildMatchingPredicate(Predicate<ClusterPredicateBuilder> predicate);
  public Boolean hasMatchingPredicate(Predicate<ClusterPredicateBuilder> predicate);
  public A withPredicates(List<ClusterPredicate> predicates);
  public A withPredicates(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.ClusterPredicate... predicates);
  public Boolean hasPredicates();
  public PlacementSpecFluent.PredicatesNested<A> addNewPredicate();
  public PlacementSpecFluent.PredicatesNested<A> addNewPredicateLike(ClusterPredicate item);
  public PlacementSpecFluent.PredicatesNested<A> setNewPredicateLike(int index,ClusterPredicate item);
  public PlacementSpecFluent.PredicatesNested<A> editPredicate(int index);
  public PlacementSpecFluent.PredicatesNested<A> editFirstPredicate();
  public PlacementSpecFluent.PredicatesNested<A> editLastPredicate();
  public PlacementSpecFluent.PredicatesNested<A> editMatchingPredicate(Predicate<ClusterPredicateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPrioritizerPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public PrioritizerPolicy getPrioritizerPolicy();
  public PrioritizerPolicy buildPrioritizerPolicy();
  public A withPrioritizerPolicy(PrioritizerPolicy prioritizerPolicy);
  public Boolean hasPrioritizerPolicy();
  public PlacementSpecFluent.PrioritizerPolicyNested<A> withNewPrioritizerPolicy();
  public PlacementSpecFluent.PrioritizerPolicyNested<A> withNewPrioritizerPolicyLike(PrioritizerPolicy item);
  public PlacementSpecFluent.PrioritizerPolicyNested<A> editPrioritizerPolicy();
  public PlacementSpecFluent.PrioritizerPolicyNested<A> editOrNewPrioritizerPolicy();
  public PlacementSpecFluent.PrioritizerPolicyNested<A> editOrNewPrioritizerPolicyLike(PrioritizerPolicy item);
  public interface PredicatesNested<N> extends Nested<N>,ClusterPredicateFluent<PlacementSpecFluent.PredicatesNested<N>>{
    public N and();
    public N endPredicate();
    
  }
  public interface PrioritizerPolicyNested<N> extends Nested<N>,PrioritizerPolicyFluent<PlacementSpecFluent.PrioritizerPolicyNested<N>>{
    public N and();
    public N endPrioritizerPolicy();
    
  }
  
}
